@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtCharts/QCandlestickSeries>
 #include <QtCharts/QCandlestickSet>
@@ -33,7 +7,7 @@
 #include <QtTest/QtTest>
 #include "tst_definitions.h"
 
-QT_CHARTS_USE_NAMESPACE
+QT_USE_NAMESPACE
 
 Q_DECLARE_METATYPE(QCandlestickSet *)
 Q_DECLARE_METATYPE(QList<QCandlestickSet *>)
@@ -81,8 +55,15 @@ private Q_SLOTS:
     void mouseDoubleClicked();
 
 private:
-    QCandlestickSeries *m_series;
-    QList<QCandlestickSet *> m_sets;
+    QPointer<QCandlestickSeries> m_series;
+    struct SetList : QList<QPointer<QCandlestickSet>> {
+        operator QList<QCandlestickSet *> () const {
+            QList<QCandlestickSet *> list;
+            for (int i = 0; i < count(); ++i)
+                list.append(at(i));
+            return list;
+        }
+    }; SetList m_sets;
 };
 
 void tst_QCandlestickSeries::initTestCase()
@@ -119,14 +100,9 @@ void tst_QCandlestickSeries::init()
 
 void tst_QCandlestickSeries::cleanup()
 {
-    foreach (QCandlestickSet *set, m_sets) {
-        m_series->remove(set);
-        m_sets.removeAll(set);
-        delete set;
-    }
-
     delete m_series;
-    m_series = nullptr;
+    qDeleteAll(m_sets);
+    m_sets.clear();
 }
 
 void tst_QCandlestickSeries::qCandlestickSeries()
@@ -177,16 +153,20 @@ void tst_QCandlestickSeries::remove()
 
     // Remove some sets
     const int removeCount = 3;
-    for (int i = 0; i < removeCount; ++i)
+    for (int i = 0; i < removeCount; ++i) {
         QVERIFY(m_series->remove(m_sets.at(i)));
+        QVERIFY(!m_sets.at(i));
+    }
     QCOMPARE(m_series->count(), m_sets.count() - removeCount);
 
     for (int i = removeCount; i < m_sets.count(); ++i)
         QCOMPARE(m_series->sets().at(i - removeCount), m_sets.at(i));
 
     // Try removing all sets again (should be ok, even if some sets have already been removed)
-    for (int i = 0; i < m_sets.count(); ++i)
+    for (int i = 0; i < m_sets.count(); ++i) {
         m_series->remove(m_sets.at(i));
+        QVERIFY(!m_sets.at(i));
+    }
     QCOMPARE(m_series->count(), 0);
 }
 
@@ -316,7 +296,7 @@ void tst_QCandlestickSeries::clear()
 void tst_QCandlestickSeries::sets()
 {
     m_series->append(m_sets);
-    QCOMPARE(m_series->sets(), m_sets);
+    QCOMPARE(m_series->sets(), (QList<QCandlestickSet *>)m_sets);
 
     for (int i = 0; i < m_sets.count(); ++i)
         QCOMPARE(m_series->sets().at(i), m_sets.at(i));
@@ -612,7 +592,7 @@ void tst_QCandlestickSeries::mouseClicked()
                                plotArea.top(), candlestickWidth, candlestickHeight));
 
     // Click set 1
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set1).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -627,7 +607,7 @@ void tst_QCandlestickSeries::mouseClicked()
     QVERIFY(setSpy1.takeFirst().isEmpty());
 
     // Click set 2
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set2).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -696,12 +676,12 @@ void tst_QCandlestickSeries::mouseHovered()
 
     QList<QVariant> seriesSpyArgs = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QCandlestickSet *>(seriesSpyArgs.at(1)), set1);
-    QCOMPARE(seriesSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(seriesSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(seriesSpyArgs.at(0).toBool(), true);
     seriesSpyArgs.clear();
 
     QList<QVariant> setSpyArgs = setSpy1.takeFirst();
-    QCOMPARE(setSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(setSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(setSpyArgs.at(0).toBool(), true);
     setSpyArgs.clear();
 
@@ -716,24 +696,24 @@ void tst_QCandlestickSeries::mouseHovered()
     // Should leave set 1
     seriesSpyArgs = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QCandlestickSet *>(seriesSpyArgs.at(1)), set1);
-    QCOMPARE(seriesSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(seriesSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(seriesSpyArgs.at(0).toBool(), false);
     // Don't call seriesSpyArgs.clear() here
 
     setSpyArgs = setSpy1.takeFirst();
-    QCOMPARE(setSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(setSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(setSpyArgs.at(0).toBool(), false);
     // Don't call setSpyArgs.clear() here
 
     // Should enter set 2
     seriesSpyArgs = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QCandlestickSet *>(seriesSpyArgs.at(1)), set2);
-    QCOMPARE(seriesSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(seriesSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(seriesSpyArgs.at(0).toBool(), true);
     seriesSpyArgs.clear();
 
     setSpyArgs = setSpy2.takeFirst();
-    QCOMPARE(setSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(setSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(setSpyArgs.at(0).toBool(), true);
     setSpyArgs.clear();
 
@@ -748,12 +728,12 @@ void tst_QCandlestickSeries::mouseHovered()
     // Should leave set 2
     seriesSpyArgs = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QCandlestickSet *>(seriesSpyArgs.at(1)), set2);
-    QCOMPARE(seriesSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(seriesSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(seriesSpyArgs.at(0).toBool(), false);
     seriesSpyArgs.clear();
 
     setSpyArgs = setSpy2.takeFirst();
-    QCOMPARE(setSpyArgs.at(0).type(), QVariant::Bool);
+    QCOMPARE(setSpyArgs.at(0).metaType().id(), QMetaType::Bool);
     QCOMPARE(setSpyArgs.at(0).toBool(), false);
     setSpyArgs.clear();
 }
@@ -791,7 +771,7 @@ void tst_QCandlestickSeries::mousePressed()
                                plotArea.top(), candlestickWidth, candlestickHeight));
 
     // Press set 1
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set1).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -806,7 +786,7 @@ void tst_QCandlestickSeries::mousePressed()
     QVERIFY(setSpy1.takeFirst().isEmpty());
 
     // Press set 2
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set2).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -854,7 +834,7 @@ void tst_QCandlestickSeries::mouseReleased()
                                plotArea.top(), candlestickWidth, candlestickHeight));
 
     // Release mouse over set 1
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set1).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -869,7 +849,7 @@ void tst_QCandlestickSeries::mouseReleased()
     QVERIFY(setSpy1.takeFirst().isEmpty());
 
     // Release mouse over set 2
-    QTest::mouseClick(view.viewport(), Qt::LeftButton, 0, layout.value(set2).center().toPoint());
+    QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.value(set2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
@@ -917,7 +897,7 @@ void tst_QCandlestickSeries::mouseDoubleClicked()
                                plotArea.top(), candlestickWidth, candlestickHeight));
 
     // Double-click set 1
-    QTest::mouseDClick(view.viewport(), Qt::LeftButton, 0, layout.value(set1).center().toPoint());
+    QTest::mouseDClick(view.viewport(), Qt::LeftButton, {}, layout.value(set1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
     QCOMPARE(seriesSpy.count(), 1);
